@@ -11,8 +11,8 @@ from typing import Any
 
 warnings.filterwarnings('ignore', message='Unverified HTTPS request')
 warnings.filterwarnings('ignore', message='aliases are no longer used by BaseSettings')
-warnings.filterwarnings('ignore', message='please do not use _builder as this may change')
-
+warnings.filterwarnings('ignore', message='DEPRECATED: please do not use _builder as this may change')
+# warnings.filterwarnings(action='ignore', category=DeprecationWarning, module='tensorflow_datasets')  # noqa                      
 
 LEVEL_COLOR_MAP = {
     "TRACE": "<cyan>",
